@@ -9,11 +9,11 @@ IO::Callback - Emulate file interface for a code reference
 
 =head1 VERSION
 
-Version 1.11_01
+Version 1.01
 
 =cut
 
-our $VERSION = '1.11_01';
+our $VERSION = '1.01';
 
 =head1 SYNOPSIS
 
@@ -344,7 +344,6 @@ sub getline
     *$self->{R} or return $self->_ebadf;
     return if *$self->{Eof} || *$self->{Err};
     my $buf = *$self->{Buf};
-    $. = *$self->{lno};
 
     unless (defined $/) {  # slurp
         1 while $self->_doread;
@@ -517,8 +516,6 @@ sub printf
 sub getpos
 {
     my $self = shift;
-
-    $. = *$self->{lno};
     return *$self->{Pos};
 }
 *tell = \&getpos;
@@ -556,9 +553,7 @@ sub write
         croak "Negative length" if $len < 0;
         if (@_ > 2) {
             $off = $_[2] || 0;
-            if ( $off >= $slen and $off > 0 and ($] < 5.011 or $off > $slen) ) {
-                croak "Offset outside string";
-            }
+            croak "Offset outside string" if $off >= $slen and $off > 0;
             if ($off < 0) {
                 $off += $slen;
                 croak "Offset outside string" if $off < 0;
@@ -621,7 +616,7 @@ Fails to inter-operate with some library modules that read or write filehandles
 
 =back
 
-Please report any other bugs or feature requests to C<bug- at rt.cpan.org>, or through
+Please report any other bugs or feature requests to C<bug-io-callback at rt.cpan.org>, or through
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=IO::Callback>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
@@ -661,16 +656,12 @@ L<IO::String>, L<IO::Stringy>, L<perlfunc/open>
 
 Adapted from code in L<IO::String> by Gisle Aas.
 
-=head1 MANITAINER
-
-This module is currently being maintained by Toby Inkster (TOBYINK)
-for bug fixes. No substantial changes or new features are planned.
-
 =head1 COPYRIGHT & LICENSE
 
 Copyright 1998-2005 Gisle Aas.
 
-Copyright 2009-2010 Dave Taylor.
+Copyright 2009 Dave Taylor, all rights reserved.
+
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
